@@ -1,6 +1,6 @@
 from .byrows_update import byrows_update
-from .export import (export_as_csv, export_as_fixture, export_as_xls,
-                     export_delete_tree,)
+from .export import (export_as_csv, export_as_fixture,
+                     export_as_xls, export_delete_tree,)
 from .graph import graph_queryset
 from .mass_update import mass_update
 from .merge import merge
