@@ -13,19 +13,21 @@ if db == 'pg':
         'default': {
             'ENGINE': 'django.db.backends.postgresql_psycopg2',
             'NAME': 'adminactions',
-            'HOST': '127.0.0.1',
-            'PORT': '',
-            'USER': 'postgres',
-            'PASSWORD': ''}}
+            'HOST': os.environ.get('PG_HOST', '127.0.0.1'),
+            'PORT': os.environ.get('PG_PORT', ''),
+            'USER': os.environ.get('PG_USER', 'postgres'),
+            'PASSWORD': os.environ.get('PG_PASSWORD', ''),
+            }}
 elif db == 'mysql':
     DATABASES = {
         'default': {
             'ENGINE': 'django.db.backends.mysql',
             'NAME': 'adminactions',
-            'HOST': '127.0.0.1',
-            'PORT': '',
-            'USER': 'root',
-            'PASSWORD': '',
+            'HOST': os.environ.get('MYSQL_HOST', '127.0.0.1'),
+            'PORT': os.environ.get('MYSQL_PORT', ''),
+            'USER': os.environ.get('MYSQL_USER', 'root'),
+            'PASSWORD': os.environ.get('MYSQL_PASSWORD', ''),
+
             'CHARSET': 'utf8',
             'COLLATION': 'utf8_general_ci',
             'TEST': {
@@ -39,10 +41,11 @@ elif db == 'myisam':
         'default': {
             'ENGINE': 'django.db.backends.mysql',
             'NAME': 'adminactions',
-            'HOST': '127.0.0.1',
-            'PORT': '',
-            'USER': 'root',
-            'PASSWORD': '',
+            'HOST': os.environ.get('MYSQL_HOST', '127.0.0.1'),
+            'PORT': os.environ.get('MYSQL_PORT', ''),
+            'USER': os.environ.get('MYSQL_USER', 'root'),
+            'PASSWORD': os.environ.get('MYSQL_PASSWORD', ''),
+
             'CHARSET': 'utf8',
             'OPTIONS': {'init_command': 'SET storage_engine=MyISAM'},
             'COLLATION': 'utf8_general_ci',
@@ -100,6 +103,7 @@ INSTALLED_APPS = [
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
+    'admin_extra_urls',
     'adminactions.apps.Config',
     'demo']
 
@@ -144,6 +148,7 @@ TEMPLATES = [
              'django.template.context_processors.media',
              'django.template.context_processors.static',
              'django.template.context_processors.tz',
+             "django.template.context_processors.request",
              'django.contrib.messages.context_processors.messages',
          ],
      },
